summaryrefslogtreecommitdiffstats
path: root/kdat/TapeFileInfoWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/TapeFileInfoWidget.h')
-rw-r--r--kdat/TapeFileInfoWidget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/TapeFileInfoWidget.h b/kdat/TapeFileInfoWidget.h
index e6f605e..60a9a1c 100644
--- a/kdat/TapeFileInfoWidget.h
+++ b/kdat/TapeFileInfoWidget.h
@@ -41,10 +41,10 @@ public:
/**
* Create a new tape file info widget.
*
* @param tqparent The tqparent widget.
* @param name The name of this widget.
*/
- TapeFileInfoWidget( TQWidget* tqparent = 0, const char* name = 0 );
+ TapeFileInfoWidget( TQWidget* parent = 0, const char* name = 0 );
/**
* Destroy the tape file info widget.
@@ -41,10 +41,10 @@ public:
* Create a new tape file info widget.
*
- * @param tqparent The tqparent widget.
+ * @param parent The parent widget.
* @param name The name of this widget.
*/